# Setup python target for shiboken so the right cmake file is imported.
%global py_suffix %(%{__python3} -c "import sysconfig; print(sysconfig.get_config_var('SOABI'))")

# Maintainers:  keep this list of plugins up to date
# List plugins in %%{_libdir}/freecad/lib, less '.so' and 'Gui.so', here
%global plugins Drawing Fem FreeCAD Image Import Inspection Mesh MeshPart Part Points QtUnit Raytracing ReverseEngineering Robot Sketcher Start Web PartDesignGui _PartDesign Path PathGui Spreadsheet SpreadsheetGui area DraftUtils DraftUtils libDriver libDriverDAT libDriverSTL libDriverUNV libE57Format libMEFISTO2 libSMDS libSMESH libSMESHDS libStdMeshers Measure TechDraw TechDrawGui libarea-native Surface SurfaceGui PathSimulator

# Some plugins go in the Mod folder instead of lib. Deal with those here:
%global mod_plugins Mod/PartDesign

%define srcname FreeCAD

# (daviddavid) re-enable system PyCXX
# https://forum.freecadweb.org/viewtopic.php?f=4&t=35109
%bcond_without pycxx
# (daviddavid) use bundled Zipios for now (upstream still use an old zipios copy)
%bcond_with zipios

Name:           freecad
Version:        0.20.2
Release:        %mkrel 4
Summary:        A general purpose 3D CAD modeler
Group:          Graphics/3D

License:        GPLv2+
URL:            https://www.freecadweb.org/
Source0:        https://github.com/%{srcname}/%{srcname}/archive/%{version}/%{srcname}-%{version}.tar.gz
Source102:      freecad.1

Patch0:         freecad-0.17-zipios.patch
Patch1:         freecad-0.17-Version_h.patch
Patch2:         freecad-unbundled-pycxx.patch

# Patches from Debian
Patch11:        fix_gcc8_ftbfs.patch
Patch12:        fix-cmake-extra-license.patch
Patch13:        disable_memory_check.patch

# Mageia patches
Patch50:        freecad-0.18.5-mga-std-endl-fix.patch

# Upstream patches

# Utilities
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  swig
BuildRequires:  graphviz
BuildRequires:  gettext
BuildRequires:  dos2unix
BuildRequires:  desktop-file-utils
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  git-core

# Development Libraries
BuildRequires:  glibc-devel
BuildRequires:  boost-devel
BuildRequires:  freeimage-devel
BuildRequires:  med-devel >= 4.0.0
BuildRequires:  hdf5-devel >= 1.12.2
BuildRequires:  opencascade-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebEngineCore)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(Qt5X11Extras)
# We use the internal smesh version with fixes atm
#BuildRequires:  smesh-devel
BuildRequires:  spnav-devel
BuildRequires:  vtk-devel
BuildRequires:  utf8cpp-devel
%if %{with zipios}
BuildRequires:  zipios++-devel
%endif
BuildRequires:  cmake(double-conversion)
BuildRequires:  cmake(pybind11)
BuildRequires:  pkgconfig(Coin)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(ompi-cxx)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(pyside2)
BuildRequires:  pkgconfig(shiboken2)
BuildRequires:  pkgconfig(freeglut)
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pyside2-tools
%if %{with pycxx}
BuildRequires:  python3dist(cxx)
%endif
BuildRequires:  python3dist(matplotlib)
BuildRequires:  python3dist(pivy)

# Packages separated because they are noarch, but not optional so require them
# here.
Requires:       %{name}-data = %{version}-%{release}

Requires:       python3dist(pivy)
Requires:       python3dist(matplotlib)
Requires:       python3dist(pycollada)
Requires:       python3-pyside2
Requires:       python3-shiboken2
Requires:       openscad

%description
FreeCAD is a general purpose Open Source 3D CAD/MCAD/CAx/CAE/PLM modeler, aimed
directly at mechanical engineering and product design but also fits a wider
range of uses in engineering, such as architecture or other engineering
specialties. It is a feature-based parametric modeler with a modular software
architecture which makes it easy to provide additional functionality without
modifying the core system.


%package data
Summary:        Data files for FreeCAD
Group:          Graphics/3D
BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}
Requires:       qttools5-assistant

%description data
Data files for FreeCAD.


%prep
%autosetup -p1 -n %{srcname}-%{version}

# Removed bundled libraries
#rm -rf src/3rdParty
%if %{with zipios}
rm -rf src/zipios++
%endif
%if %{with pycxx}
rm -rf src/CXX
%endif


%build
%cmake -DCMAKE_INSTALL_PREFIX=%{_libdir}/%{name} \
       -DCMAKE_INSTALL_LIBDIR=%{_libdir}/%{name}/lib \
       -DCMAKE_INSTALL_DATADIR=%{_datadir}/%{name} \
       -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
       -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir} \
       -DRESOURCEDIR=%{_datadir}/%{name} \
       -DOpenGL_GL_PREFERENCE=GLVND \
       -DCOIN3D_INCLUDE_DIR=%{_includedir}/Coin4 \
       -DFREECAD_USE_EXTERNAL_PIVY=TRUE \
       -DUSE_OCC=TRUE \
       -DFREECAD_USE_EXTERNAL_SMESH=FALSE \
       -DSMESH_INCLUDE_DIR=%{_includedir}/smesh \
       %if %{with zipios}
       -DFREECAD_USE_EXTERNAL_ZIPIOS=TRUE \
       %else
       -DFREECAD_USE_EXTERNAL_ZIPIOS=FALSE \
       %endif
       %if %{with pycxx}
       -DPYCXX_INCLUDE_DIR=$(pkg-config --variable=includedir PyCXX) \
       -DPYCXX_SOURCE_DIR=$(pkg-config --variable=srcdir PyCXX) \
       %endif
       -DMEDFILE_INCLUDE_DIRS=%{_includedir}/med \
       -DOPENMPI_INCLUDE_DIRS=%{_includedir} \
       -DBUILD_QT5=ON \
       -DPYTHON_EXECUTABLE=%{__python3} \
       -DSHIBOKEN_INCLUDE_DIR=%{_includedir}/shiboken2/ \
       -DSHIBOKEN_LIBRARY=%{_libdir}/libshiboken2.%{py_suffix}.so \
       -DPYSIDE_INCLUDE_DIR=%{_includedir}/PySide2/ \
       -DPYSIDE_LIBRARY=%{_libdir}/libpyside2.%{py_suffix}.so \
       -DBUILD_ENABLE_CXX_STD="C++17"

%cmake_build


%install
%cmake_install

# Launchers in /usr/bin
mkdir -p %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/FreeCAD << EOF
#!/bin/bash
LD_LIBRARY_PATH=%{_libdir}/freecad/lib %{_libdir}/freecad/bin/FreeCAD "\$@"
EOF

cat > %{buildroot}%{_bindir}/FreeCADCmd << EOF
#!/bin/bash
LD_LIBRARY_PATH=%{_libdir}/freecad/lib %{_libdir}/freecad/bin/FreeCADCmd "\$@"
EOF

chmod a+rx %{buildroot}%{_bindir}/FreeCAD
chmod a+rx %{buildroot}%{_bindir}/FreeCADCmd

# Move mis-installed files to the right location
# Need to figure out if FreeCAD can install correctly at some point.
mkdir -p %{buildroot}%{_datadir}
mv %{buildroot}%{_libdir}/%{name}/share/* \
   %{buildroot}%{_datadir}

# Install man page
install -pD -m 0644 %{SOURCE102} \
    %{buildroot}%{_mandir}/man1/%{name}.1

# Symlink manpage to other binary names
pushd %{buildroot}%{_mandir}/man1
ln -sf %{name}.1.gz FreeCAD.1.xz
ln -sf %{name}.1.gz FreeCADCmd.1.xz
popd

# Remove obsolete Start_Page.html
rm -f %{buildroot}%{_docdir}/%{name}/Start_Page.html

# Belongs in %%license not %%doc
rm -f %{buildroot}%{_docdir}/freecad/ThirdPartyLibraries.html

rm -f %{buildroot}%{_datadir}/pixmaps/freecad.xpm

%files
%license data/License.txt src/Doc/ThirdPartyLibraries.html
%doc ChangeLog.txt README.md
%{_bindir}/*
%{_metainfodir}/org.freecadweb.%{srcname}.appdata.xml
%{_datadir}/applications/org.freecadweb.%{srcname}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/scalable/apps/org.freecadweb.%{srcname}.svg
%{_iconsdir}/hicolor/scalable/mimetypes/application-x-extension-fcstd.svg
%{_datadir}/mime/packages/org.freecadweb.%{srcname}.xml
%{_datadir}/thumbnailers/%{srcname}.thumbnailer
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/bin/
%{_libdir}/%{name}/include/E57Format/E57Export.h
%{_libdir}/%{name}/lib/
%{_libdir}/%{name}/Ext/
%{_libdir}/%{name}/Mod/
%{_mandir}/man1/*.1.*

%files data
%{_datadir}/%{name}/
%{_docdir}/%{name}/LICENSE.html


%changelog
* Mon Mar 20 2023 daviddavid <daviddavid> 0.20.2-4.mga9
+ Revision: 1949840
- add python3dist(pivy) build dependency to really enable pivy support

* Sun Mar 19 2023 papoteur <papoteur> 0.20.2-3.mga9
+ Revision: 1949700
- Rebuild with QtWebengine instead of QtWebkit

* Sat Dec 24 2022 wally <wally> 0.20.2-2.mga9
+ Revision: 1926468
- rebuild for boost 1.81.0

* Mon Dec 05 2022 kekepower <kekepower> 0.20.2-1.mga9
+ Revision: 1917971
- Update to version 0.20.2

* Thu Nov 03 2022 ghibo <ghibo> 0.20.1-2.mga9
+ Revision: 1902223
- Add missed nlohmann_json to BuildRequires
- Rebuild for newer opencascade 7.6.x

* Wed Aug 10 2022 kekepower <kekepower> 0.20.1-1.mga9
+ Revision: 1876734
- Update to version 0.20.1

* Sun Jul 03 2022 wally <wally> 0.20-2.mga9
+ Revision: 1867246
- rebuild for boost 1.79.0

* Thu Jun 30 2022 papoteur <papoteur> 0.20-1.mga9
+ Revision: 1866747
- update to 0.20
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 kekepower <kekepower> 0.19.4-1.mga9
+ Revision: 1787072
- Update to version 0.19.4

* Tue Feb 22 2022 tv <tv> 0.19.3-3.mga9
+ Revision: 1782850
- Rebuild for python-3.10
+ wally <wally>
- add more upstream vtk 9 fixes via Fedora

* Wed Dec 22 2021 wally <wally> 0.19.3-2.mga9
+ Revision: 1763417
- add upstream patch via Fedora for better vtk9 compatibility
- rebuild for boost 1.78.0

* Sat Dec 11 2021 kekepower <kekepower> 0.19.3-1.mga9
+ Revision: 1761450
- Rediff Patch100: fix-Sequencer.cpp-for-qt5.15.patch
- Add upstream patch to fix build failure with Qt5.15
- Update to version 0.19.3

* Thu Sep 09 2021 wally <wally> 0.19.2-3.mga9
+ Revision: 1744660
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 0.19.2-2.mga9
+ Revision: 1722956
- rebuild for boost 1.76.0

* Mon Apr 26 2021 kekepower <kekepower> 0.19.2-1.mga9
+ Revision: 1719800
- Update to version 0.19.2

* Wed Apr 21 2021 daviddavid <daviddavid> 0.19.1-1.mga9
+ Revision: 1717791
- new version: 0.19.1
- remove merged upstream patches

* Sat Mar 20 2021 daviddavid <daviddavid> 0.18.6-4.mga9
+ Revision: 1705555
- rebuild for python 3.9

* Wed Mar 17 2021 daviddavid <daviddavid> 0.18.6-3.mga9
+ Revision: 1703997
- re-enable build of docs and examples
- build with C++17

* Wed Mar 17 2021 daviddavid <daviddavid> 0.18.6-2.mga9
+ Revision: 1703985
- Update to version 0.18.6
  o This is the final version of the 0.18 series
- update set_about_freecad patch to match with current version

* Thu Dec 31 2020 wally <wally> 0.18.5-4.mga8
+ Revision: 1666754
- rebuild for boost 1.75.0
- build with C++14

* Sun Dec 20 2020 wally <wally> 0.18.5-3.mga8
+ Revision: 1661996
- rebuild for boost 1.74.0

* Wed Dec 16 2020 umeabot <umeabot> 0.18.5-2.mga8
+ Revision: 1658451
- Rebuild for new Qt5

* Sat Dec 05 2020 kekepower <kekepower> 0.18.5-1.mga8
+ Revision: 1653143
- Fix build
- Update to version 0.18.5

* Wed Nov 04 2020 joequant <joequant> 0.18.4-9.mga8
+ Revision: 1642639
- fix build
+ daviddavid <daviddavid>
- switch to opencascade (OCC)
+ akien <akien>
- Rebuild against opencascade 7.4.0p1

* Thu Oct 29 2020 joequant <joequant> 0.18.4-8.mga8
+ Revision: 1640374
- bump build

* Thu Jun 18 2020 daviddavid <daviddavid> 0.18.4-7.mga8
+ Revision: 1595848
- rebuild for new Qt5/Pyside2/shiboken2 5.15.0 stack

* Sat Jun 06 2020 daviddavid <daviddavid> 0.18.4-6.mga8
+ Revision: 1590734
- re-enable system PyCXX

* Sat Jun 06 2020 daviddavid <daviddavid> 0.18.4-5.mga8
+ Revision: 1590727
- use fedora patch to fix build with boost 1.73
+ wally <wally>
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 0.18.4-4.mga8
+ Revision: 1544743
- Mageia 8 Mass Rebuild

* Tue Feb 11 2020 daviddavid <daviddavid> 0.18.4-3.mga8
+ Revision: 1490699
- backport upstream fixes to update FindPySide2Tools for PySide2 5.14 (issue #4229)
- rebuild for new Qt5, Pyside2 and shiboken2 5.14.1

* Sun Jan 26 2020 wally <wally> 0.18.4-2.mga8
+ Revision: 1483364
- rebuild for boost 1.72.0
- build with new cmake macros

* Sun Oct 27 2019 kekepower <kekepower> 0.18.4-1.mga8
+ Revision: 1455983
- Update to version 0.18.4
+ daviddavid <daviddavid>
- simplify the py3 suffix lib for shiboken2 and pyside2

* Thu Oct 10 2019 daviddavid <daviddavid> 0.18.3-2.mga8
+ Revision: 1450899
- add patch to fix build with python 3.8
- rebuild for python3.8
- rebuild for shiboken2/pyside2 5.13.1
- use bundled copy of zipios++ (upstream still use an old zipios copy)

* Sat Jul 27 2019 kekepower <kekepower> 0.18.3-1.mga8
+ Revision: 1424575
- Add patches from Debian
- Update to version 0.18.3

* Sat May 11 2019 kekepower <kekepower> 0.18.2-1.mga7
+ Revision: 1397314
- Update to version 0.18.2

* Mon Apr 08 2019 daviddavid <daviddavid> 0.18.1-3.mga7
+ Revision: 1386882
- add missing dependency on python3-shiboken2

* Mon Apr 08 2019 daviddavid <daviddavid> 0.18.1-2.mga7
+ Revision: 1386736
- port to Qt5 and Python3
- fix coin3d doc path for cmake detection

* Sat Apr 06 2019 kekepower <kekepower> 0.18.1-1.mga7
+ Revision: 1386329
- Update to version 0.18.1

* Tue Mar 19 2019 daviddavid <daviddavid> 0.18-1.mga7
+ Revision: 1378837
- new version: 0.18
- enable system med support
- use system pivy
- use bundled smesh for now
- use upstream desktop, appdata and mimeinfo files
+ zezinho <zezinho>
- add BR on vtk
- new version 0.17

* Tue Oct 16 2018 wally <wally> 0.16.6712-3.mga7
+ Revision: 1321032
- rebuild for new boost 1.68.0

* Tue Aug 28 2018 daviddavid <daviddavid> 0.16.6712-2.mga7
+ Revision: 1255177
- rebuild for new xerces-c 3.2.1

* Sun Apr 15 2018 daviddavid <daviddavid> 0.16.6712-1.mga7
+ Revision: 1218828
- Update to version 0.16.6712 to fix crash (mga#22858)

* Mon Dec 25 2017 wally <wally> 0.16-4.mga7
+ Revision: 1184746
- rebuild for new boost
+ tv <tv>
- rebuild for boost 1.64

* Tue Jan 31 2017 barjac <barjac> 0.16-2.mga6
+ Revision: 1084306
- Rebuild for eigen3

* Mon Jan 23 2017 daviddavid <daviddavid> 0.16-1.mga6
+ Revision: 1083251
- new version: 0.16
- remove patch which has been included upstream

* Tue Dec 29 2015 ycantin <ycantin> 0.15-6.mga6
+ Revision: 916830
- fix build : backport upstream patch for boost 1.60
+ daviddavid <daviddavid>
- rebuild for new boost 1.60.0

* Fri Oct 23 2015 ycantin <ycantin> 0.15-1.mga6
+ Revision: 894390
- imported package freecad


* Mon Jun 25 2012  <john@zultron.com> - 0.12-6
- Filter out automatically generated Provides/Requires of private libraries
- freecad.desktop not passing 'desktop-file-validate'; fixed
- Remove BuildRequires: tbb-devel and gts-devel

* Mon Jun 25 2012  <john@zultron.com> - 0.12-5
- New patch to unbundle PyCXX
- Add conditional build options for OpenCASCADE, bundled Zipios++,
  bundled PyCXX, bundled smesh

* Tue Jun 19 2012 Richard Shaw <hobbes1069@gmail.com> - 0.12-4
- Add linker flag to stop excessive linking.

* Thu May 31 2012 Richard Shaw <hobbes1069@gmail.com> - 0.12-3
- Add patch for GCC 4.7 on Fedora 17.

* Thu Nov 10 2011 Richard Shaw <hobbes1069@gmail.com> - 0.12-2
- Initial release.
